PublishTopic

Enum PublishTopic 

pub enum PublishTopic {
    Unvalidated(String),
    Validated(ValidatedTopic),
}
Topic argument accepted by publish APIs.

ValidatedTopic variants skip per-call validation while string variants are validated for MQTT topic correctness.

Variants



Unvalidated(String)

Raw topic input that must be validated before publishing.



Validated(ValidatedTopic)

Topic that has already been validated once.