pub struct AuthNotice(/* private fields */);Expand description
Wait handle returned by tracked re-authentication APIs.
Implementations
Sourceimpl AuthNotice
impl AuthNotice
Sourcepub fn wait(self) -> Result<AuthOutcome, AuthNoticeError>
pub fn wait(self) -> Result<AuthOutcome, AuthNoticeError>
Sourcepub async fn wait_async(self) -> Result<AuthOutcome, AuthNoticeError>
pub async fn wait_async(self) -> Result<AuthOutcome, AuthNoticeError>
Wait for the authentication result asynchronously.
Errors
Returns an error if the event loop drops the notice sender or if the authentication exchange fails before a result is available.