pub struct FixedHeader { /* private fields */ }Expand description
Packet type from a byte
7 3 0
+--------------------------+--------------------------+
byte 1 | MQTT Control Packet Type | Flags for each type |
+--------------------------+--------------------------+
| Remaining Bytes Len (1/2/3/4 bytes) |
+-----------------------------------------------------+
<https://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc385349207>Implementations
Sourceimpl FixedHeader
impl FixedHeader
pub const fn new( byte1: u8, remaining_len_len: usize, remaining_len: usize, ) -> FixedHeader
Sourcepub const fn packet_type(&self) -> Result<PacketType, Error>
pub const fn packet_type(&self) -> Result<PacketType, Error>
Returns the MQTT packet type represented by this fixed header.
Errors
Returns an error if the fixed-header flags are invalid for the decoded packet type.
Sourcepub const fn frame_length(&self) -> usize
pub const fn frame_length(&self) -> usize
Returns the size of full packet (fixed header + variable header + payload) Fixed header is enough to get the size of a frame in the stream