SubscribeNotice

Struct SubscribeNotice 

pub struct SubscribeNotice(/* private fields */);
Wait handle returned by tracked subscribe APIs.

Implementations

Source

impl SubscribeNotice

pub fn wait(self) -> Result<SubAck, SubscribeNoticeError>

Wait for SubAck by blocking the current thread.

Errors

Returns an error if the event loop drops the notice sender or if the subscribe fails before a SubAck is available.

Panics

Panics if called in an async context.

pub async fn wait_async(self) -> Result<SubAck, SubscribeNoticeError>

Wait for SubAck asynchronously.

Errors

Returns an error if the event loop drops the notice sender or if the subscribe fails before a SubAck is available.

pub fn wait_completion(self) -> Result<(), SubscribeNoticeError>

Wait for subscribe completion and treat failing SubAck return codes as completion errors.

Errors

Returns an error if the subscribe fails before SubAck, or if SubAck contains failing return codes.

Panics

Panics if called in an async context.

pub async fn wait_completion_async(self) -> Result<(), SubscribeNoticeError>

Wait asynchronously for subscribe completion and treat failing SubAck return codes as completion errors.

Errors

Returns an error if the subscribe fails before SubAck, or if SubAck contains failing return codes.