EventLoop

Struct EventLoop 

pub struct EventLoop {
    pub options: MqttOptions,
    pub state: MqttState,
    /* private fields */
}
Eventloop with all the state of a connection

Fields

options: MqttOptions

Options of the current mqtt connection

state: MqttState

Current state of the connection

Implementations

Source

impl EventLoop

pub fn new(options: MqttOptions, cap: usize) -> Self

New MQTT EventLoop

When connection encounters critical errors (like auth failure), user has a choice to access and update options, state and requests.

pub fn clean(&mut self)

Last session might contain packets which aren’t acked. MQTT says these packets should be republished in the next session. Move pending messages from state to eventloop, drops the underlying network connection and clears the keepalive timeout if any.

NOTE: Use only when EventLoop is blocked on network and unable to immediately handle disconnect. Pending requests are managed internally by the event loop. Use pending_len or pending_is_empty for observation-only checks.

pub fn pending_len(&self) -> usize

Number of pending requests queued for retransmission.

pub fn pending_is_empty(&self) -> bool

Returns true when there are no pending requests queued for retransmission.

pub fn drain_pending_as_failed(&mut self, reason: NoticeFailureReason) -> usize

Drains pending retransmission queue and fails tracked notices with the given reason.

Returns the number of pending requests removed from the queue.

pub fn reset_session_state(&mut self)

Clears eventloop and state tracking bound to a previous session.

pub async fn poll(&mut self) -> Result<Event, ConnectionError>

Yields Next notification or outgoing request and periodically pings the broker. Continuing to poll will reconnect to the broker if there is a disconnection. NOTE Don’t block this while iterating

Errors

Returns a ConnectionError if connecting, reading, writing, or protocol handling fails.