pub struct SubscribeNotice(/* private fields */);Expand description
Wait handle returned by tracked subscribe APIs.
Implementations
Sourceimpl SubscribeNotice
impl SubscribeNotice
Sourcepub fn wait(self) -> Result<SubAck, SubscribeNoticeError>
pub fn wait(self) -> Result<SubAck, SubscribeNoticeError>
Sourcepub async fn wait_async(self) -> Result<SubAck, SubscribeNoticeError>
pub async fn wait_async(self) -> Result<SubAck, SubscribeNoticeError>
Wait for SubAck asynchronously.
Errors
Returns an error if the event loop drops the notice sender or if the
subscribe fails before a SubAck is available.
Sourcepub fn wait_completion(self) -> Result<(), SubscribeNoticeError>
pub fn wait_completion(self) -> Result<(), SubscribeNoticeError>
Sourcepub async fn wait_completion_async(self) -> Result<(), SubscribeNoticeError>
pub async fn wait_completion_async(self) -> Result<(), SubscribeNoticeError>
Wait asynchronously for subscribe completion and treat failing SubAck
return codes as completion errors.
Errors
Returns an error if the subscribe fails before SubAck, or if SubAck
contains failing return codes.